const fz = require('zigbee-herdsman-converters/converters/fromZigbee');
const tz = require('zigbee-herdsman-converters/converters/toZigbee');
const exposes = require('zigbee-herdsman-converters/lib/exposes');
const reporting = require('zigbee-herdsman-converters/lib/reporting');
const extend = require('zigbee-herdsman-converters/lib/extend');
const e = exposes.presets;
const ea = exposes.access;


const definition = [
{
    fingerprint: [{modelID: 'TS0215A', manufacturerName: '_TZ3000_oxbicfmc'}],
    model: 'TS0215A_sos',
    vendor: 'Justplus',
    description: 'SOS button',
    fromZigbee: [fz.command_emergency, fz.battery],
    exposes: [e.battery(), e.action(['emergency'])],
    toZigbee: [],
},    
{
    fingerprint: [{modelID: 'TS0202', manufacturerName: '_TYZB01_nt6xdqxx'}],
    model: 'RH3040',
    vendor: 'Justplus',
    description: 'Motion sensor',
    fromZigbee: [fz.ias_occupancy_alarm_1, fz.battery, fz.ignore_basic_report, fz.ias_occupancy_alarm_1_report],
    toZigbee: [],
    exposes: [e.occupancy(), e.battery_low(), e.tamper(), e.battery()],
},
{
    fingerprint: [{modelID: 'TS0601', manufacturerName: '_TZE200_adquvgsi'}],
    model: 'RTCGQ13LM',
    vendor: 'Justplus',
    description: 'Motion sensor',
    fromZigbee: [fz.ias_occupancy_alarm_1, fz.ignore_basic_report, fz.ias_occupancy_alarm_1_report],
    toZigbee: [],
    exposes: [e.occupancy()],
},
{
    fingerprint: [{modelID: 'TS0601', manufacturerName: '_TZE200_uebojraa'},{modelID: 'TS0601', manufacturerName: '_TZE200_yh7aoahi'}],
    model: 'TS0601_smoke',
    vendor: 'Justplus',
    description: 'Smoke sensor',
    fromZigbee: [fz.tuya_smoke, fz.battery],
    toZigbee: [],
    configure: async (device, coordinatorEndpoint, logger) => {
        const endpoint = device.getEndpoint(1);
        await reporting.bind(endpoint, coordinatorEndpoint, ['genBasic']);
    },
    exposes: [e.battery(), e.smoke(), e.battery_low()],
},
{
    fingerprint: [{modelID: 'TS011F', manufacturerName: '_TZ3000_hghcgnpk'}],
    model: 'TS011F_2_gang_wall',
    vendor: 'Justplus',
    description: '2 gang wall outlet and 1 USB',
    extend: extend.switch(),
    meta: {multiEndpoint: true},    
    endpoint: (device) => {
        return {'l1': 1, 'l2': 2};
    },
    exposes: [e.switch().withEndpoint('l1'), e.switch().withEndpoint('l2')],
},
];


module.exports = definition;
